==> zio-aws-dataexchange_2.13-5.17.295.15-sources.jar: zio/aws/dataexchange/model/JobErrorLimitName.scala <==
package zio.aws.dataexchange.model
import scala.jdk.CollectionConverters._
sealed trait JobErrorLimitName {
  def unwrap
      : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName
}
object JobErrorLimitName {
  def wrap(
      value: software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName
  ): zio.aws.dataexchange.model.JobErrorLimitName = value match {
    case software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.ASSETS_PER_REVISION =>
      val r = `Assets per revision`
      r
    case software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.ASSET_SIZE_IN_GB =>
      val r = `Asset size in GB`
      r
    case software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.AMAZON_REDSHIFT_DATASHARE_ASSETS_PER_REVISION =>
      val r = `Amazon Redshift datashare assets per revision`
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.dataexchange.model.JobErrorLimitName {
    override def unwrap
        : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName =
      software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.UNKNOWN_TO_SDK_VERSION
  }
  case object `Assets per revision`
      extends zio.aws.dataexchange.model.JobErrorLimitName {
    override def unwrap
        : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName =
      software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.ASSETS_PER_REVISION
  }
  case object `Asset size in GB`
      extends zio.aws.dataexchange.model.JobErrorLimitName {
    override def unwrap
        : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName =
      software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.ASSET_SIZE_IN_GB
  }
  case object `Amazon Redshift datashare assets per revision`
      extends zio.aws.dataexchange.model.JobErrorLimitName {
    override def unwrap
        : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName =
      software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.AMAZON_REDSHIFT_DATASHARE_ASSETS_PER_REVISION
  }
}

==> zio-aws-dataexchange_2.13-7.21.15.7-sources.jar: zio/aws/dataexchange/model/JobErrorLimitName.scala <==
package zio.aws.dataexchange.model
import scala.jdk.CollectionConverters._
sealed trait JobErrorLimitName {
  def unwrap
      : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName
}
object JobErrorLimitName {
  def wrap(
      value: software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName
  ): zio.aws.dataexchange.model.JobErrorLimitName = value match {
    case software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.ASSETS_PER_REVISION =>
      val r = `Assets per revision`
      r
    case software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.ASSET_SIZE_IN_GB =>
      val r = `Asset size in GB`
      r
    case software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.AMAZON_REDSHIFT_DATASHARE_ASSETS_PER_REVISION =>
      val r = `Amazon Redshift datashare assets per revision`
      r
    case software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.AWS_LAKE_FORMATION_DATA_PERMISSION_ASSETS_PER_REVISION =>
      val r = `AWS Lake Formation data permission assets per revision`
      r
    case software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.AMAZON_S3_DATA_ACCESS_ASSETS_PER_REVISION =>
      val r = `Amazon S3 data access assets per revision`
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.dataexchange.model.JobErrorLimitName {
    override def unwrap
        : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName =
      software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.UNKNOWN_TO_SDK_VERSION
  }
  case object `Assets per revision`
      extends zio.aws.dataexchange.model.JobErrorLimitName {
    override def unwrap
        : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName =
      software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.ASSETS_PER_REVISION
  }
  case object `Asset size in GB`
      extends zio.aws.dataexchange.model.JobErrorLimitName {
    override def unwrap
        : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName =
      software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.ASSET_SIZE_IN_GB
  }
  case object `Amazon Redshift datashare assets per revision`
      extends zio.aws.dataexchange.model.JobErrorLimitName {
    override def unwrap
        : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName =
      software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.AMAZON_REDSHIFT_DATASHARE_ASSETS_PER_REVISION
  }
  case object `AWS Lake Formation data permission assets per revision`
      extends zio.aws.dataexchange.model.JobErrorLimitName {
    override def unwrap
        : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName =
      software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.AWS_LAKE_FORMATION_DATA_PERMISSION_ASSETS_PER_REVISION
  }
  case object `Amazon S3 data access assets per revision`
      extends zio.aws.dataexchange.model.JobErrorLimitName {
    override def unwrap
        : software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName =
      software.amazon.awssdk.services.dataexchange.model.JobErrorLimitName.AMAZON_S3_DATA_ACCESS_ASSETS_PER_REVISION
  }
}
